# -*- coding: utf-8 -*-
import json, datetime
try:
    from urllib2 import urlopen, Request
except ImportError:
    from urllib.request import urlopen, Request
try:
    from urllib import quote
except ImportError:
    from urllib.parse import quote
try:
    from urlparse import urlparse, parse_qs, urljoin
except ImportError:
    from urllib.parse import urlparse, parse_qs, urljoin
ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/87.0.4280.88 Safari/537.36'


def getjson(url):
    request = Request(url, headers={'User-Agent': ua})
    return json.loads(urlopen(request).read().decode('utf-8'))


def search(s, page=1):
    if not s:
        return {'code': 'bilibili 300'}
    url = 'https://api.bilibili.com/x/web-interface/search/type?keyword=%s&search_type=video&page=%d' % (quote(s), page)
    try:
        data = getjson(url)
    except Exception as e:
        return {'code': 'haitum 201', 'error': str(e)}
    ret = []
    for e in data['data']['result']:
        title = e['title']
        title = title.replace('<em class="keyword">', '')
        title = title.replace('</em>', '')
        plot = []
        plot.append(e['author'])
        plot.append(datetime.datetime.utcfromtimestamp(e['pubdate']).strftime('%Y-%m-%d %H:%M:%S'))
        plot.append(e['description'])
        plot = '\n'.join(plot)
        ret.append({'title': title, 'url': 'https://www.bilibili.com/video/%s' % e['bvid'], 'img': urljoin(url, e['pic']), 'plot': plot})
    if page < int(data['data']['numPages']):
        ret.append({'title': 'Next Page (%d)' % (page + 1), 'search': s, 'page': page + 1})
    return ret


def videolist(url):
    o = urlparse(url)
    p = o.path.split('/')
    q = parse_qs(o.query, True)
    url1 = 'https://api.bilibili.com/x/player/pagelist?bvid=%s' % p[-1]
    if 'p' in q:
        return ykdl(url)
    try:
        data = getjson(url1)
    except Exception as e:
        return {'code': 'haitum 301', 'error': str(e)}
    if len(data['data']) == 1:
        return ykdl(url)
    ret = []
    for e in data['data']:
        ret.append({'title': '%d. %s' % (e['page'], e['part']), 'url': 'https://www.bilibili.com/video/%s?p=%d' % (url, e['page'])})
    return ret


def ykdl(url):
    from ykdlWrapper import url_to_module
    m, u = url_to_module(url)
    parser = m.parser
    parser(u)
    info = m.prepare()
    info = info.jsonlize()
    ret = []
    for k, v in info['streams'].items():
        ret.append({'title': k, 'url': v['src']})
    return ret
